# Generated by roxygen2: do not edit by hand

S3method(plot,quickSentiment_prc)
S3method(plot,quickSentiment_roc)
S3method(print,quickSentiment_eval)
export(BOW_test)
export(BOW_train)
export(evaluate_performance)
export(logit_model)
export(nb_model)
export(pipeline)
export(pre_process)
export(predict_sentiment)
export(qs_negations)
export(rf_model)
export(xgb_model)
importFrom(Matrix,Diagonal)
importFrom(doParallel,registerDoParallel)
importFrom(foreach,registerDoSEQ)
importFrom(glmnet,cv.glmnet)
importFrom(graphics,abline)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(magrittr,"%>%")
importFrom(methods,as)
importFrom(naivebayes,multinomial_naive_bayes)
importFrom(parallel,detectCores)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(quanteda,dfm)
importFrom(quanteda,dfm_match)
importFrom(quanteda,dfm_tfidf)
importFrom(quanteda,dfm_weight)
importFrom(quanteda,docfreq)
importFrom(quanteda,featnames)
importFrom(quanteda,ndoc)
importFrom(quanteda,tokens)
importFrom(quanteda,tokens_ngrams)
importFrom(quanteda,tokens_select)
importFrom(ranger,ranger)
importFrom(stats,predict)
importFrom(stopwords,stopwords)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_squish)
importFrom(textstem,lemmatize_strings)
importFrom(xgboost,xgb.DMatrix)
importFrom(xgboost,xgb.cv)
importFrom(xgboost,xgb.train)
